from setuptools import setup

setup(name='ha_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['ha_distributions'],
      author='Hanny',
      author_email='hanny.aly@gmail.com',
      zip_safe=False)
